Model
=====

.. currentmodule:: hhpy.modelling

.. autoclass:: Model
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~Model.fit
      ~Model.predict

   .. rubric:: Methods Documentation

   .. automethod:: fit
   .. automethod:: predict
